Spelling fixes

Spelling errors found using github.com/lucasdemarchi/codespell
A tool to fix common misspellings.
This tool is licensed under GNU General Public License, version 2.

Change-Id: Iefb2ad70d313a4800cd413c7c2e5e2154bec49fb
Signed-off-by: Gunnar Mills <gmills@us.ibm.com>
diff --git a/configure.ac b/configure.ac
index 1e6afd0..94de978 100644
--- a/configure.ac
+++ b/configure.ac
@@ -27,7 +27,7 @@
 PKG_CHECK_MODULES([PHOSPHOR_LOGGING], [phosphor-logging], ,
 [AC_MSG_ERROR([The openbmc/phosphor-logging package is required])])
 PKG_CHECK_MODULES([SYSTEMD], [libsystemd >= 221], ,
-[AC_MSG_ERROR([Could not find systemd...systemd developement package required])])
+[AC_MSG_ERROR([Could not find systemd...systemd development package required])])
 PKG_CHECK_MODULES([PHOSPHOR_DBUS_INTERFACES], [phosphor-dbus-interfaces], ,
 [AC_MSG_ERROR([Could not find phosphor-dbus-interfaces...openbmc/phosphor-dbus-interfaces package required])])
 PKG_CHECK_MODULES([LIBEVDEV], [libevdev], ,
diff --git a/cooling-type/argument.cpp b/cooling-type/argument.cpp
index cfd8b25..2c9a580 100644
--- a/cooling-type/argument.cpp
+++ b/cooling-type/argument.cpp
@@ -80,7 +80,7 @@
     std::cerr <<
               "    --path=<objpath>     *Required* object path under inventory "
               "to have CoolingType updated\n";
-    std::cerr << "\nThe --air / --water options may be given in addtion to "
+    std::cerr << "\nThe --air / --water options may be given in addition to "
               "--gpio, in which case both their setting and the GPIO will take "
               "effect.\n";
     std::cerr << std::flush;
diff --git a/presence/pfpgen.py b/presence/pfpgen.py
index 187be32..efae7cc 100755
--- a/presence/pfpgen.py
+++ b/presence/pfpgen.py
@@ -185,7 +185,7 @@
 
     def setup(self, objs):
         '''All policies have an associated fan and methods.
-        Resolve the indicies.'''
+        Resolve the indices.'''
 
         sensors = []
         for s in self.sensors:
@@ -323,7 +323,7 @@
             # is just an array index.
             #
             # At this point all objects have been created but references
             # have not been resolved to array indicies.  Instruct objects
             # to do that now.
             for cls, items in objs.items():
                 for obj in items:
@@ -323,7 +323,7 @@
             #
             # At this point all objects have been created but references
-            # have not been resolved to array indicies.  Instruct objects
+            # have not been resolved to array indices.  Instruct objects
             # to do that now.
             for cls, items in objs.items():